NRouterBinaryResponse typedef
Raw bytes paired with the metadata and status reported by the gateway.
Implementation
typedef NRouterBinaryResponse = ({
List<int> bytes,
NRouterResponseMeta meta,
int statusCode,
});
Raw bytes paired with the metadata and status reported by the gateway.
typedef NRouterBinaryResponse = ({
List<int> bytes,
NRouterResponseMeta meta,
int statusCode,
});