PromptSelection class
Constructors
-
PromptSelection({String? templateId, Map<
String, dynamic> variables = const {}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateId → String?
-
final
-
variables
→ Map<
String, dynamic> -
final
Methods
-
applyTo(
Map< String, dynamic> extra) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withVariables(
Map< String, dynamic> newVars) → PromptSelection
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited